aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CanonicalizationMethodType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CanonicalizationMethodType.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CanonicalizationMethodType.java54
1 files changed, 27 insertions, 27 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CanonicalizationMethodType.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CanonicalizationMethodType.java
index 6215e3c..894ab80 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CanonicalizationMethodType.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/CanonicalizationMethodType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,31 +10,31 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
/**
- * <p>Java class for CanonicalizationMethodType complex type.
+ * <p>Java-Klasse für CanonicalizationMethodType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="CanonicalizationMethodType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence>
- * &lt;any maxOccurs="unbounded" minOccurs="0"/>
- * &lt;/sequence>
- * &lt;attribute name="Algorithm" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" />
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="CanonicalizationMethodType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence&gt;
+ * &lt;any maxOccurs="unbounded" minOccurs="0"/&gt;
+ * &lt;/sequence&gt;
+ * &lt;attribute name="Algorithm" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -58,7 +58,7 @@ public class CanonicalizationMethodType {
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the content property.
*
* <p>
@@ -70,8 +70,8 @@ public class CanonicalizationMethodType {
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link String }
* {@link Object }
+ * {@link String }
*
*
*/
@@ -83,7 +83,7 @@ public class CanonicalizationMethodType {
}
/**
- * Gets the value of the algorithm property.
+ * Ruft den Wert der algorithm-Eigenschaft ab.
*
* @return
* possible object is
@@ -95,7 +95,7 @@ public class CanonicalizationMethodType {
}
/**
- * Sets the value of the algorithm property.
+ * Legt den Wert der algorithm-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -58,7 +58,7 @@ public class CanonicalizationMethodType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the content property.
*